<?php
/*
Plugin Name: A Graceful Sidebar Plugin
Plugin URI: http://mlynn.org/graceful-sidebar-plugin
Tags: custom sidebar, pages sidebar, custom sidebar
Description: Creates a custom sidebar widget to display a custom field from a page.  Create a page or post, enable the widget in your sidebar and add content. Create custom fields called graceful_title and graceful_content. <a href="https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=KKFYUAMPCQHXQ">Donate</a>
Version: 1.0.7
Author: Michael Lynn
Author URI: http://www.mlynn.org/
*/

add_action("init", "gs_widget_init");
add_action("admin_init", "gs_widget_admininit");
add_action('save_post','gs_save_meta');
register_activation_hook( __FILE__, 'gs_activation' );

function gs_activation() {

}

function gs_save_meta(){
    global $post;
    // Clean up legacy
    $custom = get_post_custom($post->ID);
    $graceful_title_legacy = $custom["graceful_title"][0];
    $graceful_content_legacy = $custom["graceful_content"][0];
// version 1.07 hides graceful variables from custom fields

    if ($graceful_title_legacy!='') {
        // this means we have a legacy custom field - need to move it to the new '_graceful' field to hide it from custom fields
        delete_post_meta($post->ID, "graceful_title");
    }   

    if ($graceful_content_legacy!='') {
        // this means we have a legacy custom field - need to move it to the new '_graceful' field to hide it from custom fields
        delete_post_meta($post->ID, "graceful_content");
    }   
    update_post_meta($post->ID, "_graceful_title", $_POST["_graceful_title"]);
    update_post_meta($post->ID, "_graceful_content", $_POST["_graceful_content"]);
}

function gs_widget_init() {

  register_sidebar_widget('Graceful Sidebar Widget', 'gs_widget');
  register_widget_control('Graceful Sidebar Widget', 'gs_widget_control', '500', '500');

}

function gs_widget_admininit() {

	add_meta_box('gs_meta', 'Graceful Sidebar Options', 'gs_meta', 'post', 'normal', 'high'); 
	add_meta_box('gs_meta', 'Graceful Sidebar Options', 'gs_meta', 'page', 'normal', 'high'); 

}

function gs_meta() {
	global $post;

    $custom = get_post_custom($post->ID);
    $graceful_title_legacy = $custom["graceful_title"][0];
    $graceful_content_legacy = $custom["graceful_content"][0];
// version 1.07 hides graceful variables from custom fields
    $graceful_title = $custom["_graceful_title"][0];
    $graceful_content = $custom["_graceful_content"][0];

	// Clean up legacy
	if ($graceful_title_legacy!='' && $graceful_title=='') {
		// this means we have a legacy custom field - need to move it to the new '_graceful' field to hide it from custom fields

		update_post_meta($post->ID, "_graceful_title", $graceful_title_legacy);
		delete_post_meta($post->ID, "graceful_title");

		$graceful_title = $graceful_title_legacy;
	}
	if ($graceful_content_legacy!='' && $graceful_content=='') {
		// this means we have a legacy custom field - need to move it to the new '_graceful' field to hide it from custom fields

		update_post_meta($post->ID, "_graceful_content", $graceful_content_legacy);
		delete_post_meta($post->ID, "graceful_content");
		$graceful_content = $graceful_content_legacy;
	}
	?>
	<p>This content will be displayed in the sidebar for this post or page - ONLY for this post or page.  Be certain that you enable the Graceful Sidebar Widget by dragging it to a sidebar area in your theme from the Appearances->Widgets administration panel.  <a href=http://www.mlynn.org/graceful-sidebar-plugin>More Information</a><p>
	<table class='widefat settings post'>
		<thead>
			<tr>
				<th>Graceful Sidebar Title</th>
				<th>Graceful Sidebar Content</th>
			</tr>
		</thead>
		<tbody>
			<tr>
				<td><input name=_graceful_title type=text size=40 value='<?php echo $graceful_title;?>'></td>
				<td><div id=editorcontainer><textarea id="content" name='_graceful_content' rows=8 cols=90><?php echo $graceful_content;?></textarea></div></td>
			</tr>
		</tbody>
	</table>
	<?php
}

///////////////////////////////////////////////////////////////
// gs_widget
// abstract: Displays widget content for current post or page 
// args    : 
// returns :
// globals : $post
///////////////////////////////////////////////////////////////
function gs_widget($args) {

	global $post;
	if (is_single() || is_page()) {
		extract($args);
		$gs_widget_options = unserialize(get_option('gs_widget_options'));

		$title_legacy = get_post_meta($post->ID, 'graceful_title', true);
		$content_legacy = get_post_meta($post->ID, 'graceful_content', true);

		$title = get_post_meta($post->ID, '_graceful_title', true);
		$content = get_post_meta($post->ID, '_graceful_content', true);

		if ($title_legacy!='' && $title == '') {
			// still have legacy custom fields - move them to new fields with _'s to hide them from custom field display
			$title = $title_legacy;
		}
		if ($content_legacy!='' && $content == '') {
			// still have legacy custom fields - move them to new fields with _'s to hide them from custom field display
			$content = $content_legacy;
		}
		if ( $title || $content ) {

			if ( $title ) {
				echo $before_widget;
				echo $before_title;
				echo $title;
				echo $after_title;
			}

			if ( $content ) {
				echo $content;
			}

			echo $after_widget;
		}
	}
}

///////////////////////////////////////////////////////////////
// gs_widget_control
// abstract: Displays control panel item for widget 
// args    : 
// returns : 
// globals : 
///////////////////////////////////////////////////////////////
function gs_widget_control() {

	if(!get_option('custom_widget_options')) {
		add_option('gs_widget_options', serialize(array('title'=>'Graceful Sidebar', 'text'=>'')));
	}
	  echo 'This widget will display the content you specify in the title and content specified in the post or page edit screen.   If a post or page does not have these fields, this widget will not be displayed.<p>Like the plugin?  Consider <a href=mailto:merlynn@gmail.com>emailing the author</a> or <a href="https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=KKFYUAMPCQHXQ">making a donation.</a>';

}  

